==> jc-1.4.0.tar.gz: gnu/java/nio/charset/UTF__5f8.h <==
// final class gnu.java.nio.charset.UTF_8

// class file dependencies
// @dep_class 32188cc6eff012f0 gnu_java_nio_charset_UTF__5f8
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a594354b5ffbd332 java_nio_charset_Charset

// header file dependencies
// @dep_header java_nio_charset_Charset

#include "java/nio/charset/Charset.h"

#ifndef _JC_gnu_java_nio_charset_UTF__5f8_H_
#define _JC_gnu_java_nio_charset_UTF__5f8_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CharsetDecoder$object;
struct _jc_java_nio_charset_CharsetEncoder$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$sub_refs	_jc_gnu_java_nio_charset_UTF__5f8$sub_refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$sub_nonrefs	_jc_gnu_java_nio_charset_UTF__5f8$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$refs	_jc_gnu_java_nio_charset_UTF__5f8$refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$nonrefs	_jc_gnu_java_nio_charset_UTF__5f8$nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$object	_jc_gnu_java_nio_charset_UTF__5f8$object;

typedef const struct _jc_gnu_java_nio_charset_UTF__5f8$vmethods	_jc_gnu_java_nio_charset_UTF__5f8$vmethods;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f8$vtable	_jc_gnu_java_nio_charset_UTF__5f8$vtable;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f8$vtype	_jc_gnu_java_nio_charset_UTF__5f8$vtype;

// Constructors
extern void _jc_gnu_java_nio_charset_UTF__5f8$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *);

// Virtual methods
extern jboolean _jc_gnu_java_nio_charset_UTF__5f8$method$contains$6dc00deccaf89e6e(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *, struct _jc_java_nio_charset_Charset$object *);
extern struct _jc_java_nio_charset_CharsetDecoder$object *_jc_gnu_java_nio_charset_UTF__5f8$method$newDecoder$a8155f7e01d3e07a(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *);
extern struct _jc_java_nio_charset_CharsetEncoder$object *_jc_gnu_java_nio_charset_UTF__5f8$method$newEncoder$d60e26d796f39211(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f8$method_info$contains$6dc00deccaf89e6e;
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f8$method_info$newDecoder$a8155f7e01d3e07a;
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f8$method_info$newEncoder$d60e26d796f39211;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_UTF__5f8$vmethods {
	jboolean	(*contains$6dc00deccaf89e6e)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *, struct _jc_java_nio_charset_Charset$object *);
	struct _jc_java_nio_charset_CharsetDecoder$object	*(*newDecoder$a8155f7e01d3e07a)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *);
	struct _jc_java_nio_charset_CharsetEncoder$object	*(*newEncoder$d60e26d796f39211)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *);
};

// Vtable
struct _jc_gnu_java_nio_charset_UTF__5f8$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_Charset$vmethods	java_nio_charset_Charset;
	_jc_gnu_java_nio_charset_UTF__5f8$vmethods	gnu_java_nio_charset_UTF__5f8;
};

// Vtype
struct _jc_gnu_java_nio_charset_UTF__5f8$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_UTF__5f8$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f8$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f8$refs {
    _jc_gnu_java_nio_charset_UTF__5f8$sub_refs	gnu_java_nio_charset_UTF__5f8;
    _jc_java_nio_charset_Charset$sub_refs	java_nio_charset_Charset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f8$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f8$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_Charset$sub_nonrefs	java_nio_charset_Charset;
    _jc_gnu_java_nio_charset_UTF__5f8$sub_nonrefs	gnu_java_nio_charset_UTF__5f8;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_UTF__5f8$object {
	_jc_gnu_java_nio_charset_UTF__5f8$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_UTF__5f8$vtype	*vtype;
	_jc_gnu_java_nio_charset_UTF__5f8$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_UTF__5f8$vtype _jc_gnu_java_nio_charset_UTF__5f8$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_UTF__5f8, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_UTF__5f8$class_object;

#endif	/* _JC_gnu_java_nio_charset_UTF__5f8_H_ */

==> jc-1.4.5.tar.gz: gnu/java/nio/charset/UTF__5f8.h <==
// final class gnu.java.nio.charset.UTF_8

// class file dependencies
// @dep_class 32188cc6eff012f0 gnu_java_nio_charset_UTF__5f8
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4793f288d91002f4 java_nio_charset_Charset

// header file dependencies
// @dep_header java_nio_charset_Charset

#include "java/nio/charset/Charset.h"

#ifndef _JC_gnu_java_nio_charset_UTF__5f8_H_
#define _JC_gnu_java_nio_charset_UTF__5f8_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CharsetDecoder$object;
struct _jc_java_nio_charset_CharsetEncoder$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$sub_refs	_jc_gnu_java_nio_charset_UTF__5f8$sub_refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$sub_nonrefs	_jc_gnu_java_nio_charset_UTF__5f8$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$refs	_jc_gnu_java_nio_charset_UTF__5f8$refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$nonrefs	_jc_gnu_java_nio_charset_UTF__5f8$nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f8$object	_jc_gnu_java_nio_charset_UTF__5f8$object;

typedef const struct _jc_gnu_java_nio_charset_UTF__5f8$vmethods	_jc_gnu_java_nio_charset_UTF__5f8$vmethods;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f8$vtable	_jc_gnu_java_nio_charset_UTF__5f8$vtable;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f8$vtype	_jc_gnu_java_nio_charset_UTF__5f8$vtype;

// Constructors
extern void _jc_gnu_java_nio_charset_UTF__5f8$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_nio_charset_UTF__5f8$method$contains$6dc00deccaf89e6e(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *, struct _jc_java_nio_charset_Charset$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_charset_CharsetDecoder$object *_jc_gnu_java_nio_charset_UTF__5f8$method$newDecoder$a8155f7e01d3e07a(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *) _JC_JCNI_ATTR;
extern struct _jc_java_nio_charset_CharsetEncoder$object *_jc_gnu_java_nio_charset_UTF__5f8$method$newEncoder$d60e26d796f39211(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f8$method_info$contains$6dc00deccaf89e6e;
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f8$method_info$newDecoder$a8155f7e01d3e07a;
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f8$method_info$newEncoder$d60e26d796f39211;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_UTF__5f8$vmethods {
	jboolean	(*contains$6dc00deccaf89e6e)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *, struct _jc_java_nio_charset_Charset$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_charset_CharsetDecoder$object	*(*newDecoder$a8155f7e01d3e07a)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *) _JC_JCNI_ATTR;
	struct _jc_java_nio_charset_CharsetEncoder$object	*(*newEncoder$d60e26d796f39211)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f8$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_charset_UTF__5f8$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_Charset$vmethods	java_nio_charset_Charset;
	_jc_gnu_java_nio_charset_UTF__5f8$vmethods	gnu_java_nio_charset_UTF__5f8;
};

// Vtype
struct _jc_gnu_java_nio_charset_UTF__5f8$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_UTF__5f8$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f8$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f8$refs {
    _jc_gnu_java_nio_charset_UTF__5f8$sub_refs	gnu_java_nio_charset_UTF__5f8;
    _jc_java_nio_charset_Charset$sub_refs	java_nio_charset_Charset;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f8$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f8$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_Charset$sub_nonrefs	java_nio_charset_Charset;
    _jc_gnu_java_nio_charset_UTF__5f8$sub_nonrefs	gnu_java_nio_charset_UTF__5f8;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_UTF__5f8$object {
	_jc_gnu_java_nio_charset_UTF__5f8$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_UTF__5f8$vtype	*vtype;
	_jc_gnu_java_nio_charset_UTF__5f8$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_UTF__5f8$vtype _jc_gnu_java_nio_charset_UTF__5f8$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_UTF__5f8, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_UTF__5f8$class_object;

#endif	/* _JC_gnu_java_nio_charset_UTF__5f8_H_ */
